/*
 * zioP.h	Internal header for libzio, including required
 *		standard glibc header, zlib.h, and bzlib.h.
 *		Making the used libz and bzlib functions weak symbols.
 *
 * Copyright 2004 Werner Fink, 2004 SuSE LINUX AG, Germany.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Author:      Werner Fink <werner@suse.de>
 */

#ifndef _ZIO_P_H
#define _ZIO_P_H

#ifndef _GNU_SOURCE
#  define _GNU_SOURCE
#endif
#include <stdio.h>
#include <string.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <fcntl.h>
#include <libio.h>
#include <unistd.h>
#include <stdlib.h>
#include <errno.h>
#include <zlib.h>

extern gzFile  gzopen  __P ((const char*, const char*)) __attribute__((weak));
extern int     gzread  __P ((gzFile, voidp, unsigned)) __attribute__((weak));
#ifdef ZLIB_VERNUM
extern int     gzwrite __P ((gzFile, voidpc, unsigned)) __attribute__((weak));
#else
extern int     gzwrite __P ((gzFile, const voidp, unsigned)) __attribute__((weak));
#endif
extern z_off_t gzseek  __P ((gzFile, z_off_t, int)) __attribute__((weak));
extern int     gzclose __P ((gzFile)) __attribute__((weak));

#include <bzlib.h>

extern BZFILE* BZ2_bzopen  __P ((const char *path, const char *mode)) __attribute__((weak));
extern int     BZ2_bzread  __P ((BZFILE*, void*, int)) __attribute__((weak));
extern int     BZ2_bzwrite __P ((BZFILE*, void*, int)) __attribute__((weak));
extern int     BZ2_bzflush __P ((BZFILE*)) __attribute__((weak));
extern void    BZ2_bzclose __P ((BZFILE*)) __attribute__((weak));

#if defined __GLIBC__ && __GLIBC__ > 1
#  undef  LIBIO_IS_FIXED
#  if __GLIBC__ > 2 || (__GLIBC__ >= 2 && __GLIBC_MINOR__ > 0)
#    define LIBIO_IS_FIXED
#  endif
#else
#  error libzio requires glibc
#endif

#ifndef LIBIO_IS_FIXED
typedef _IO_cookie_io_functions_t cookie_io_functions_t;
typedef ssize_t cookie_read_function_t  __P ((void *, char *, size_t));
typedef ssize_t cookie_write_function_t __P ((void *, const char *, size_t));
typedef int     cookie_seek_function_t  __P ((void *, off_t, int));
typedef int     cookie_close_function_t __P ((void *));
#endif

#endif /* _ZIO_P_H */
